CircularCorrelationCompositionModule
====================================

.. currentmodule:: pykeen.nn.compositions

.. autoclass:: CircularCorrelationCompositionModule
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~CircularCorrelationCompositionModule.func

   .. rubric:: Methods Documentation

   .. automethod:: func
